Crate lgp

Crate lgp 

A library to solve problems using linear genetic programming!

Provides a bootstrapped implementation to help you start exploring problems immediately.

Modules

core
extensions
problems
utils