pub struct IrisState { /* private fields */ }Trait Implementations
Sourceimpl State for IrisState
impl State for IrisState
fn get_value(&self, idx: usize) -> f64
Sourcefn execute_action(&mut self, action: usize) -> f64
fn execute_action(&mut self, action: usize) -> f64
Updates the impact of the factor.
For example, if data[0] has been accessed, we increase the index so data[1] is accessed next (in classification).
In RL, we act on the environment and internally update the termination state, and hold the new state.